#!/bin/ksh

# ====== setup part ======

# set the workdir variable and call the setenv.sh 
WORKDIR=`dirname $0`
. $WORKDIR/setenv.sh

# set first part of the classpath
CP1=$WCS_JCE_CLASSPATH:$WCS_HOME/lib:$WCS_HOME/lib/wcsruntime.jar:$WCS_HOME/lib/wcsconfig.jar:$WCS_HOME/lib/xml4j.jar

# set the path to the xerces.jar file. if there is none under WAS, use one under WCS
if [[ "$WAS_HOME" = "" ]]
then
   CP2=$WCS_HOME/lib/xerces.jar
else
   CP2=$WAS_HOME/lib/xerces.jar
fi

# examine the database classpath. DBDRIVERCP is classpath to JDBC driver, DBTYPE is name of db installed
DBDRIVERCP=$DB2_DRIVER:$ORACLE_CLASSPATH:$ORACLE_HOME/bin

DBTYPE=$1
# if no DBTYPE is set then exit because it is required later on
if [[ "$DBTYPE" = "" ]]
then
   echo "Database type not provided."
   exit 1
else
    # if DBTYPE is not set correctly then exit because it is required later on
    if [[ ! "$DBTYPE" = "oracle" ]]
    then
        if [[ ! "$DBTYPE" = "db2" ]]
        then
            echo "Database type not correct."
            exit 1
        fi
    fi
fi



# finaly, set the classpath for the tool   
CP=$DBDRIVERCP:$CP1:$CP2:.

# ====== execution part ======
# the correct configuration file is copied to the temp directory based on db installed. See step above...
# if the java app encounters any errors, it will return exit code of 1 

# the configuration file name has to be DBUpdate.txt
cp -f CCInfoDBUpdate.$DBTYPE.txt $WCTEMPDIR/DBUpdate.txt
cd $WCTEMPDIR
${JAVA_EXE?} -Xmx512m -cp $CP com.ibm.commerce.dbupdatetool.MKChangeApp $2 >> $WCLOGDIR/CCInfoMigration.log 2> $WCLOGDIR/MigrateEncryptedInfoError.log
if [[ "$?" = "1" ]]
then
    echo "Migration Failed."
    rm -f DBUpdate.txt
    cd ../bin
    exit 1
fi

# cleanup before another step
rm -f DBUpdate.txt
cd ../bin

cp -f ../schema/$DBTYPE/migration/DBUpdate.txt $WCTEMPDIR
cd $WCTEMPDIR
${JAVA_EXE?} -Xmx512m -cp $CP com.ibm.commerce.dbupdatetool.MKChangeApp $2 $3 $4 >> $WCLOGDIR/MKChangeUserAndCCInfoMigration.log 2> $WCLOGDIR/MigrateEncryptedInfoError.log
if [[ "$?" = "1" ]]
then
    echo "Migration Failed."
    rm -f DBUpdate.txt
    cd ../bin
    exit 1
fi
    
echo "Migration OK."
rm -f DBUpdate.txt
cd ../bin

exit 0


